**    ModelEco : MODELling in mathematical programming for the ECOnomic analysis of agriculture    **

*-----------------------------------------------------------------------------*
$Ontext
Name              modelEco_ParisBasin_technic_excel.gms
Sequence         2 - The farm model
GAMS language    tables and 2-dimensional variables
Type             LP
Description
" A farmer in the Paris basin has a 100 ha arable crop farm. He can grow soft wheat (Wheat), rapeseed, spring barley (SBarley) and winter barley (WBarley).
For each crop, he can choose between three management systems :
-Intensive (written  intens ) : it is the most intensive technology in terms of chemical inputs, with a preventive use of phytosanitary products.
-Sustainable (written  Sust ) : it involves sustainable practices.
Phytosanitary treatments are determined following the observation of diseases or pests in the plot.
The quantities used are adapted to the situation.
-Integrated pest management ( written  IPM ) : such practices integrate prophylactic agronomic measures which contribute to a decrease in the pressure caused by pests.
They can involve considerations concerning sowing dates, variety choices, crop successions in a plot, etc
The farmer knows the expected yields, the variable costs, and the labour needs for each technology and each crop.
He can work 2000 hours a year.
The selling price of soft wheat is 180/ton, that of rapeseed is 365/ton, that of spring barley is 155/ton, and that of winter barley 155/t.
The objective of the farmer is to maximize his income.
"

The data come from : Ecophyto R&D vers des systmes de culture conomes en produits phytosanitaires   Volet 1.
 Tome II : Analyse comparative de diffrents systmes en grandes cultures.
Janvier 2009. INRA et le ministre de lcologie, de lnergie, du dveloppement durable et de lamnagement du territoire.

$offtext

*-----------------------------------------------------------------------------*


*----------                      DECLARATIONS                       ----------*

SET
C        Crops                     /Wheat, Rapeseed, SBarley, WBarley/
MS       management system         /Intens,Sust,IPM/
;


scalar
Land_A        land availability               /100/
Labour_A      labour availability in hours   /2000/
;

parameter SellingPrice(C)
/Wheat 180, Rapeseed 365, SBarley 170, WBarley 155/  ;

parameter T_Costs(C, MS)    total costs per crop and per management system

;

parameter Yield(C, MS)       yield per crop and per management systems in quintals per HA

;

parameter LabourNeeds(C, MS)   labour needs per crops and management system

;

parameter
GM(C, MS)        calculated gross margin

$CALL GDXXRW.EXE dataParisBasin.xlsx o=dataParisBasin.gdx index=repertory!A3
$GDXIN dataParisBasin.gdx
$LOAd T_Costs,Yield,LabourNeeds
$GDXIN

display   T_Costs, Yield,LabourNeeds ;

*----------                          MODEL                        ----------*
variables
Z
X
IFT_tot
;

positive variables
X
;

equations
objective         objective function
land              land equation
labour            labour equation
;

objective..       sum[(C,MS), X(C,MS)* GM(C,MS)] =e= Z;
land..            sum[(C,MS), X(C,MS)] =l= Land_A ;
labour..          sum[(C,MS), X(C,MS)*LabourNeeds(C,MS)] =l= Labour_A ;

model farmModel model with technique  /all/;

*----------                        SOLUTION                         ----------*

GM(C, MS) = Yield(C,MS)*SellingPrice(C)/10 - T_Costs(C,MS)
;
display GM ;

solve farmModel using LP maximizing Z ;





